@@ -2,7 +2,6 @@
 # flake8: noqa
 from . import types
 
-
 _FUNCTIONS = [
     ('AddGeometryColumn', None,
      '''Adds a geometry column to an existing table.'''),
@@ -224,7 +223,7 @@ _FUNCTIONS = [
      '''Makes a geometry from WKB with the given SRID'''),
     ('ST_WKBToSQL', types.Geometry,
      '''Return a specified ST_Geometry value from Well-Known Binary representation (WKB). This is an alias name for ST_GeomFromWKB that takes no srid'''),
-    ('ST_Box2dFromGeoHash', types.Geometry,
+    ('ST_Box2dFromGeoHash', None,  # return an unsupported Box2d object
      '''Return a BOX2D from a GeoHash string.'''),
     ('ST_GeomFromGeoHash', types.Geometry,
      '''Return a geometry from a GeoHash string.'''),
@@ -247,7 +246,7 @@ _FUNCTIONS = [
     ('ST_AsText', None,
      '''Return the Well-Known Text (WKT) representation of the geometry/geography without SRID metadata.'''),
     ('ST_AsBinary', None,
-     '''Return the Well-Known Binary (WKB) representation of the geometry/geography without SRID meta data.'''),
+     '''[gometry] Return the Well-Known Binary (WKB) representation of the geometry/geography without SRID meta data.\nOR\n[raster] Return the Well-Known Binary (WKB) representation of the raster.'''),
     ('ST_AsEWKB', None,
      '''Return the Well-Known Binary (WKB) representation of the geometry with SRID meta data.'''),
     ('ST_AsHEXEWKB', None,
@@ -474,21 +473,21 @@ _FUNCTIONS = [
      '''Window function that returns a cluster id for each input geometry using the K-means algorithm.'''),
     ('ST_ClusterWithin', types.Geometry,
      '''Aggregate function that clusters the input geometries by separation distance.'''),
-    ('Box2D', types.Geometry,
+    ('Box2D', None,  # return an unsupported Box2d object
      ('''Returns a BOX2D representing the 2D extent of the geometry.''', 'Box2D_type')),
-    ('Box3D', types.Geometry,
+    ('Box3D', None,  # return an unsupported Box3d object
      ('''[geometry] Returns a BOX3D representing the 3D extent of the geometry.\nOR\n[raster] Returns the box 3d representation of the enclosing box of the raster.''', 'Box3D_type')),
-    ('ST_EstimatedExtent', types.Geometry,
+    ('ST_EstimatedExtent', None,  # return an unsupported Box2d object
      '''Return the 'estimated' extent of a spatial table.'''),
     ('ST_Expand', types.Geometry,
      '''Returns a bounding box expanded from another bounding box or a geometry.'''),
-    ('ST_Extent', types.Geometry,
+    ('ST_Extent', None,  # return an unsupported Box2d object
      '''an aggregate function that returns the bounding box that bounds rows of geometries.'''),
-    ('ST_3DExtent', types.Geometry,
+    ('ST_3DExtent', None,  # return an unsupported Box3d object
      '''an aggregate function that returns the 3D bounding box that bounds rows of geometries.'''),
-    ('ST_MakeBox2D', types.Geometry,
+    ('ST_MakeBox2D', None,  # return an unsupported Box2d object
      '''Creates a BOX2D defined by two 2D point geometries.'''),
-    ('ST_3DMakeBox', types.Geometry,
+    ('ST_3DMakeBox', None,  # return an unsupported Box3d object
      '''Creates a BOX3D defined by two 3D point geometries.'''),
     ('ST_XMax', None,
      '''Returns the X maxima of a 2D or 3D bounding box or a geometry.'''),
@@ -557,7 +556,7 @@ _FUNCTIONS = [
     ('ST_3DArea', None,
      '''Computes area of 3D surface geometries. Will return 0 for solids.'''),
     ('ST_Tesselate', types.Geometry,
-     '''Perform surface Tesselation of a polygon or polyhedralsurface and returns as a TIN or collection of TINS'''),
+     '''Perform surface Tessellation of a polygon or polyhedralsurface and returns as a TIN or collection of TINS'''),
     ('ST_Volume', None,
      '''Computes the volume of a 3D solid. If applied to surface (even closed) geometries will return 0.'''),
     ('ST_MakeSolid', types.Geometry,
@@ -602,14 +601,6 @@ _FUNCTIONS = [
      '''Returns the version number of the postgis.sql script released with the installed postgis lib.'''),
     ('PostGIS_Version', None,
      '''Returns PostGIS version number and compile-time options.'''),
-    ('postgis.backend', None,
-     ('''The backend to service a function where GEOS and SFCGAL overlap. Options: geos or sfcgal. Defaults to geos.''', 'postgis_backend')),
-    ('postgis.gdal_datapath', None,
-     ('''A configuration option to assign the value of GDAL's GDAL_DATA option. If not set, the environmentally set GDAL_DATA variable is used.''', 'postgis_gdal_datapath')),
-    ('postgis.gdal_enabled_drivers', None,
-     ('''A configuration option to set the enabled GDAL drivers in the PostGIS environment. Affects the GDAL configuration variable GDAL_SKIP.''', 'postgis_gdal_enabled_drivers')),
-    ('postgis.enable_outdb_rasters', None,
-     ('''A boolean configuration option to enable access to out-db raster bands.''', 'postgis_enable_outdb_rasters')),
     ('PostGIS_AddBBox', types.Geometry,
      '''Add bounding box to the geometry.'''),
     ('PostGIS_DropBBox', types.Geometry,
@@ -760,7 +751,7 @@ _FUNCTIONS = [
      ('''Return a raster value from a Well-Known Binary (WKB) raster.''', 'RT_ST_RastFromWKB')),
     ('ST_RastFromHexWKB', types.Raster,
      ('''Return a raster value from a Hex representation of Well-Known Binary (WKB) raster.''', 'RT_ST_RastFromHexWKB')),
-    ('ST_AsBinary/ST_AsWKB', None,
+    ('ST_AsWKB', None,
      ('''Return the Well-Known Binary (WKB) representation of the raster.''', 'RT_ST_AsBinary')),
     ('ST_AsHexWKB', None,
      ('''Return the Well-Known Binary (WKB) in Hex representation of the raster.''', 'RT_ST_AsHexWKB')),
