@@ -29,6 +29,8 @@ from geoalchemy2 import _spatial_idx_name
 from geoalchemy2 import func
 
 writer = rewriter.Rewriter()
+"""Rewriter object for Alembic."""
+
 _SPATIAL_TABLES = set()
 
 
@@ -96,6 +98,30 @@ def render_item(obj_type, obj, autogen_context):
     return False
 
 
+def include_object(obj, name, obj_type, reflected, compare_to):
+    """Do not include internal tables of spatial extensions.
+
+    .. warning::
+        This function only checks the table names, so it might exclude tables that should not be.
+        In such case, you should create your own function to handle your specific table names.
+
+    """
+    if (
+        obj_type == "table"
+        and (
+            name.startswith("geometry_columns")
+            or name.startswith("spatial_ref_sys")
+            or name.startswith("spatialite_history")
+            or name.startswith("sqlite_sequence")
+            or name.startswith("views_geometry_columns")
+            or name.startswith("virts_geometry_columns")
+            or name.startswith("idx_")
+        )
+    ):
+        return False
+    return True
+
+
 @Operations.register_operation("add_geospatial_column")
 @BatchOperations.register_operation(
     "add_geospatial_column", "batch_add_geospatial_column"
@@ -388,8 +414,8 @@ def create_geospatial_table(operations, operation):
     table_name = operation.table_name
     bind = operations.get_bind()
 
-    # For now the default events defined in geoalchemy2 are enought to handle table creation
-    operations.create_table(table_name, *operation.columns, **operation.kw)
+    # For now the default events defined in geoalchemy2 are enough to handle table creation
+    operations.create_table(table_name, *operation.columns, schema=operation.schema, **operation.kw)
 
     if bind.dialect.name == "sqlite":
         _SPATIAL_TABLES.add(table_name)
@@ -436,7 +462,13 @@ def create_geo_table(context, revision, op):
     )
 
     if gis_cols:
-        new_op = CreateGeospatialTableOp(op.table_name, op.columns, op.schema)
+        new_op = CreateGeospatialTableOp(
+            op.table_name,
+            op.columns,
+            op.schema,
+            op._namespace_metadata,
+            op._constraints_included,
+        )
     else:
         new_op = op
 
