@@ -45,6 +45,23 @@ in several ways:
 
       session.scalar(lake.geom.ST_Area())
 
+.. warning::
+
+    A few functions (like `ST_Transform()`, `ST_Union()`, `ST_SnapToGrid()`, ...) can be used on
+    several spatial types (:class:`geoalchemy2.types.Geometry`,
+    :class:`geoalchemy2.types.Geography` and / or :class:`geoalchemy2.types.Raster` types). In
+    GeoAlchemy2, these functions are only defined for the :class:`geoalchemy2.types.Geometry` type,
+    as it can not be defined for several types at the same time. Therefore, using these functions on
+    :class:`geoalchemy2.types.Geography` or :class:`geoalchemy2.types.Raster` requires minor
+    tweaking to enforce the type by passing the `type_=Geography` or `type_=Raster` argument to the
+    function::
+
+        s = select([func.ST_Transform(
+                            lake_table.c.raster,
+                            2154,
+                            type_=Raster)
+                        .label('transformed_raster')])
+
 Reference
 ---------
 
@@ -52,31 +69,63 @@ Reference
 import re
 
 from sqlalchemy import inspect
+from sqlalchemy.ext.compiler import compiles
+from sqlalchemy.sql import annotation
 from sqlalchemy.sql import functions
 from sqlalchemy.sql.elements import ColumnElement
-from sqlalchemy.ext.compiler import compiles
-from sqlalchemy.util import with_metaclass
 
 from . import elements
 from ._functions import _FUNCTIONS
 
+try:
+    # SQLAlchemy < 2
 
-class _GenericMeta(functions._GenericMeta):
-    """Extend the metaclass mechanism of sqlalchemy to register the functions in
-    a specific registry for geoalchemy2"""
+    from sqlalchemy.sql.functions import _GenericMeta
+    from sqlalchemy.util import with_metaclass
 
-    _register = False
+    class _GeoGenericMeta(_GenericMeta):
+        """Extend the metaclass mechanism of sqlalchemy to register the functions in
+        a specific registry for geoalchemy2"""
 
-    def __init__(cls, clsname, bases, clsdict):
-        # Register the function
-        elements.function_registry.add(clsname.lower())
+        _register = False
 
-        super(_GenericMeta, cls).__init__(clsname, bases, clsdict)
+        def __init__(cls, clsname, bases, clsdict):
+            # Register the function
+            elements.function_registry.add(clsname.lower())
+
+            super(_GeoGenericMeta, cls).__init__(clsname, bases, clsdict)
+
+    _GeoFunctionBase = with_metaclass(_GeoGenericMeta, functions.GenericFunction)
+    _GeoFunctionParent = functions.GenericFunction
+except ImportError:
+    # SQLAlchemy >= 2
+
+    class GeoGenericFunction(functions.GenericFunction):
+        def __init_subclass__(cls) -> None:
+            if annotation.Annotated not in cls.__mro__:
+                cls._register_geo_function(cls.__name__, cls.__dict__)
+            super().__init_subclass__()
+
+        @classmethod
+        def _register_geo_function(cls, clsname, clsdict):
+            # Check _register attribute status
+            cls._register = getattr(cls, "_register", True)
+
+            # Register the function if required
+            if cls._register:
+                elements.function_registry.add(clsname.lower())
+            else:
+                # Set _register to True to register child classes by default
+                cls._register = True
+
+    _GeoFunctionBase = GeoGenericFunction
+    _GeoFunctionParent = GeoGenericFunction
 
 
 class TableRowElement(ColumnElement):
 
     inherit_cache = False
+    """The cache is disabled for this class."""
 
     def __init__(self, selectable):
         self.selectable = selectable
@@ -86,12 +135,13 @@ class TableRowElement(ColumnElement):
         return [self.selectable]
 
 
-class ST_AsGeoJSON(with_metaclass(_GenericMeta, functions.GenericFunction)):
+class ST_AsGeoJSON(_GeoFunctionBase):
     """Special process for the ST_AsGeoJSON() function to be able to work with its
     feature version introduced in PostGIS 3."""
 
     name = "ST_AsGeoJSON"
     inherit_cache = True
+    """The cache is enabled for this class."""
 
     def __init__(self, *args, **kwargs):
         expr = kwargs.pop('expr', None)
@@ -117,7 +167,7 @@ class ST_AsGeoJSON(with_metaclass(_GenericMeta, functions.GenericFunction)):
                 except Exception:
                     continue
 
-        functions.GenericFunction.__init__(self, *args, **kwargs)
+        _GeoFunctionParent.__init__(self, *args, **kwargs)
 
     __doc__ = (
         'Return the geometry as a GeoJSON "geometry" object, or the row as a '
@@ -150,7 +200,7 @@ def _compile_table_row_thing(element, compiler, **kw):
     return compiled.split(".")[0]
 
 
-class GenericFunction(with_metaclass(_GenericMeta, functions.GenericFunction)):
+class GenericFunction(_GeoFunctionBase):
     """
     The base class for GeoAlchemy functions.
 
@@ -196,7 +246,7 @@ class GenericFunction(with_metaclass(_GenericMeta, functions.GenericFunction)):
                     func_name = elem.geom_from
                     func_args = [elem.data, elem.srid]
                 args[idx] = getattr(functions.func, func_name)(*func_args)
-        functions.GenericFunction.__init__(self, *args, **kwargs)
+        _GeoFunctionParent.__init__(self, *args, **kwargs)
 
 
 # Iterate through _FUNCTIONS and create GenericFunction classes dynamically
@@ -255,6 +305,21 @@ def _compiles_sqlite(cls, fn):
     compiles(globals()[cls], "sqlite")(_compile_sqlite)
 
 
-for cls, fn in _SQLITE_FUNCTIONS.items():
-    _compiles_default(cls)
-    _compiles_sqlite(cls, fn)
+def register_sqlite_mapping(mapping):
+    """Register compilation mappings for the given functions.
+
+    Args:
+        mapping: Should have the following form::
+
+                {
+                    "function_name_1": "sqlite_function_name_1",
+                    "function_name_2": "sqlite_function_name_2",
+                    ...
+                }
+    """
+    for cls, fn in mapping.items():
+        _compiles_default(cls)
+        _compiles_sqlite(cls, fn)
+
+
+register_sqlite_mapping(_SQLITE_FUNCTIONS)
