@@ -7,21 +7,22 @@ kind of functions.
 """
 import pytest
 from pkg_resources import parse_version
-
-from sqlalchemy import __version__ as SA_VERSION
 from sqlalchemy import Column
-from sqlalchemy import create_engine
 from sqlalchemy import Float
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
-from sqlalchemy import select
+from sqlalchemy import __version__ as SA_VERSION
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import sessionmaker
 
-from geoalchemy2 import Raster, WKTElement
+from geoalchemy2 import Raster
+from geoalchemy2 import WKTElement
 from geoalchemy2.functions import GenericFunction
 from geoalchemy2.types import CompositeType
 
+# Tests imports
+from tests import select
+from tests import test_only_with_dialects
+
 
 class SummaryStatsCustomType(CompositeType):
     """Define the composite type returned by the function ST_SummaryStatsAgg."""
@@ -45,15 +46,12 @@ class ST_SummaryStatsAgg(GenericFunction):
     inherit_cache = True
 
 
-engine = create_engine('postgresql://gis:gis@localhost/gis', echo=True)
-metadata = MetaData(engine)
+metadata = MetaData()
 Base = declarative_base(metadata=metadata)
-session = sessionmaker(bind=engine)()
 
 
 class Ocean(Base):
     __tablename__ = 'ocean'
-    __table_args__ = {'schema': 'public'}
     id = Column(Integer, primary_key=True)
     rast = Column(Raster)
 
@@ -61,21 +59,16 @@ class Ocean(Base):
         self.rast = rast
 
 
+@test_only_with_dialects("postgresql")
 class TestSTSummaryStatsAgg():
 
-    def setup(self):
-        metadata.drop_all(checkfirst=True)
-        metadata.create_all()
-
-    def teardown(self):
-        session.rollback()
-        metadata.drop_all()
-
     @pytest.mark.skipif(
         parse_version(SA_VERSION) < parse_version("1.4"),
         reason="requires SQLAlchely>1.4",
     )
-    def test_st_summary_stats_agg(self):
+    def test_st_summary_stats_agg(self, session, conn):
+        metadata.drop_all(conn, checkfirst=True)
+        metadata.create_all(conn)
 
         # Create a new raster
         polygon = WKTElement('POLYGON((0 0,1 1,0 1,0 0))', srid=4326)
@@ -84,23 +77,23 @@ class TestSTSummaryStatsAgg():
         session.flush()
 
         # Define the query to compute stats
-        stats_agg = select(
+        stats_agg = select([
             Ocean.rast.ST_SummaryStatsAgg_custom(1, True, 1).label("stats")
-        )
+        ])
         stats_agg_alias = stats_agg.alias("stats_agg")
 
         # Use these stats
-        query = select(
+        query = select([
             stats_agg_alias.c.stats.count.label("count"),
             stats_agg_alias.c.stats.sum.label("sum"),
             stats_agg_alias.c.stats.mean.label("mean"),
             stats_agg_alias.c.stats.stddev.label("stddev"),
             stats_agg_alias.c.stats.min.label("min"),
             stats_agg_alias.c.stats.max.label("max")
-        )
+        ])
 
         # Check the query
-        assert str(query) == (
+        assert str(query.compile(dialect=session.bind.dialect)) == (
             "SELECT "
             "(stats_agg.stats).count AS count, "
             "(stats_agg.stats).sum AS sum, "
@@ -111,10 +104,10 @@ class TestSTSummaryStatsAgg():
             "FROM ("
             "SELECT "
             "ST_SummaryStatsAgg("
-            "public.ocean.rast, "
+            "ocean.rast, "
             "%(ST_SummaryStatsAgg_1)s, %(ST_SummaryStatsAgg_2)s, %(ST_SummaryStatsAgg_3)s"
             ") AS stats \n"
-            "FROM public.ocean) AS stats_agg"
+            "FROM ocean) AS stats_agg"
         )
 
         # Execute the query
