@@ -8,21 +8,21 @@ are projected in the DB. To avoid having to always tweak the query with a
 ``ST_Transform()``, it is possible to define a `TypeDecorator
 <https://docs.sqlalchemy.org/en/13/core/custom_types.html#sqlalchemy.types.TypeDecorator>`_
 """
-from sqlalchemy import create_engine
-from sqlalchemy import MetaData
 from sqlalchemy import Column
 from sqlalchemy import Integer
+from sqlalchemy import MetaData
 from sqlalchemy import func
+from sqlalchemy import text
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import sessionmaker
 from sqlalchemy.types import TypeDecorator
 
 from geoalchemy2 import Geometry
 from geoalchemy2 import shape
 
+# Tests imports
+from tests import test_only_with_dialects
 
-engine = create_engine('postgresql://gis:gis@localhost/gis', echo=True)
-metadata = MetaData(engine)
+metadata = MetaData()
 
 Base = declarative_base(metadata=metadata)
 
@@ -31,33 +31,53 @@ class TransformedGeometry(TypeDecorator):
     """This class is used to insert a ST_Transform() in each insert or select."""
     impl = Geometry
 
+    cache_ok = True
+
     def __init__(self, db_srid, app_srid, **kwargs):
         kwargs["srid"] = db_srid
-        self.impl = self.__class__.impl(**kwargs)
+        super().__init__(**kwargs)
         self.app_srid = app_srid
         self.db_srid = db_srid
 
     def column_expression(self, col):
-        """The column_expression() method is overrided to ensure that the
-        SRID of the resulting WKBElement is correct"""
+        """The column_expression() method is overridden to set the correct type.
+
+        This is needed so that the returned element will also be decorated. In this case we don't
+        want to transform it again afterwards so we set the same SRID to both the ``db_srid`` and
+        ``app_srid`` arguments.
+        Without this the SRID of the WKBElement would be wrong.
+        """
         return getattr(func, self.impl.as_binary)(
             func.ST_Transform(col, self.app_srid),
-            type_=self.__class__.impl(srid=self.app_srid)
-            # srid could also be -1 so that the SRID is deduced from the
-            # WKB data
+            type_=self.__class__(db_srid=self.app_srid, app_srid=self.app_srid)
         )
 
     def bind_expression(self, bindvalue):
         return func.ST_Transform(
-            self.impl.bind_expression(bindvalue), self.db_srid)
+            self.impl.bind_expression(bindvalue), self.db_srid,
+            type_=self,
+        )
 
 
 class ThreeDGeometry(TypeDecorator):
     """This class is used to insert a ST_Force3D() in each insert."""
     impl = Geometry
 
+    cache_ok = True
+
+    def column_expression(self, col):
+        """The column_expression() method is overridden to set the correct type.
+
+        This is not needed in this example but it is needed if one wants to override other methods
+        of the TypeDecorator class, like ``process_result_value()`` for example.
+        """
+        return getattr(func, self.impl.as_binary)(col, type_=self)
+
     def bind_expression(self, bindvalue):
-        return func.ST_Force3D(self.impl.bind_expression(bindvalue))
+        return func.ST_Force3D(
+            self.impl.bind_expression(bindvalue),
+            type=self,
+        )
 
 
 class Point(Base):
@@ -71,26 +91,19 @@ class Point(Base):
         ThreeDGeometry(srid=4326, geometry_type="POINTZ", dimension=3))
 
 
-session = sessionmaker(bind=engine)()
-
-
 def check_wkb(wkb, x, y):
     pt = shape.to_shape(wkb)
     assert round(pt.x, 5) == x
     assert round(pt.y, 5) == y
 
 
+@test_only_with_dialects("postgresql")
 class TestTypeDecorator():
 
-    def setup(self):
-        metadata.drop_all(checkfirst=True)
-        metadata.create_all()
+    def _create_one_point(self, session, conn):
+        metadata.drop_all(conn, checkfirst=True)
+        metadata.create_all(conn)
 
-    def teardown(self):
-        session.rollback()
-        metadata.drop_all()
-
-    def _create_one_point(self):
         # Create new point instance
         p = Point()
         p.raw_geom = "SRID=4326;POINT(5 45)"
@@ -104,8 +117,8 @@ class TestTypeDecorator():
 
         return p.id
 
-    def test_transform(self):
-        self._create_one_point()
+    def test_transform(self, session, conn):
+        self._create_one_point(session, conn)
 
         # Query the point and check the result
         pt = session.query(Point).one()
@@ -117,7 +130,7 @@ class TestTypeDecorator():
         check_wkb(pt.geom, 5, 45)
 
         # Check that the data is correct in DB using raw query
-        q = "SELECT id, ST_AsEWKT(geom) AS geom FROM point;"
+        q = text("SELECT id, ST_AsEWKT(geom) AS geom FROM point;")
         res_q = session.execute(q).fetchone()
         assert res_q.id == 1
         assert res_q.geom == "SRID=2154;POINT(857581.899319668 6435414.7478354)"
@@ -126,7 +139,7 @@ class TestTypeDecorator():
         pt_trans = session.query(
             Point,
             Point.raw_geom,
-            func.ST_Transform(Point.raw_geom, 2154).label("trans")
+            func.ST_Transform(Point.raw_geom, 2154).label("trans"),
         ).one()
 
         assert pt_trans[0].id == 1
@@ -143,8 +156,8 @@ class TestTypeDecorator():
         assert pt_trans[2].srid == 2154
         check_wkb(pt_trans[2], 857581.89932, 6435414.74784)
 
-    def test_force_3d(self):
-        self._create_one_point()
+    def test_force_3d(self, session, conn):
+        self._create_one_point(session, conn)
 
         # Query the point and check the result
         pt = session.query(Point).one()
