@@ -1,9 +1,14 @@
 import re
-import pytest
 
-from sqlalchemy import Table, MetaData, Column, select
+import pytest
+from sqlalchemy import Column
+from sqlalchemy import MetaData
+from sqlalchemy import Table
+
 from geoalchemy2.types import Geometry
 
+from . import select
+
 
 def eq_sql(a, b):
     a = re.sub(r'[\n\t]', '', str(a))
